import click

from pathlib import Path

from .config import Config


@click.group("cli")
@click.pass_context
def cli(ctx):
	"Unofficial Linux launcher for Project Torque"

	ctx.obj = Config()

	try:
		ctx.obj.load()

	except FileNotFoundError:
		ctx.obj.save()


@cli.command("locate")
@click.option("-d", "--directory", help = "Base directory to search from")
@click.pass_context
def cli_locate_bin(ctx, directory: str = None):
	"Search for 'ProjectTorque.exe' and set it as the game binary"

	search_path = Path(directory or "~/.steam").expanduser().resolve()
	click.echo(f"Searching '{search_path}' for 'ProjectTorque.exe'")

	try:
		path = ctx.obj.locate_bin(directory)
		ctx.obj.save()
		click.echo(f"Found game binary at '{path}'")

	except FileNotFoundError:
		click.echo("Could not find game binary")


@cli.command("setup")
@click.option("-n", "--nuke", is_flag = True, help = "Nuke the WINE prefix before continuing")
@click.pass_context
def cli_setup(ctx, nuke: bool = False):
	"Setup the WINE prefix for Project Torque"

	click.echo("Setting up WINE prefix")
	ctx.obj.setup(nuke = nuke)

	if not ctx.obj.binpath.exists():
		click.echo("Finding path to Project Torque binary")

		try:
			ctx.obj.locate_bin_from_steam_config()
			ctx.obj.save()

		except FileNotFoundError as e:
			click.echo(str(e))
			return

	click.echo("Launcher setup finished :3")


@cli.command("run", context_settings = {"allow_extra_args": True})
@click.pass_context
def cli_run(ctx):
	"Run Project Torque"

	if ctx.args and ctx.args[-1].lower().endswith("projecttorque.exe"):
		ctx.obj.binpath = Path(ctx.args[-1]).expanduser().resolve()

	ctx.obj.run()


def main():  # pylint: disable=missing-function-docstring
	cli(prog_name = "ptlaunch")  # pylint: disable=no-value-for-parameter
